# PySoundSphere

PySoundSphere is a high level audio library written in python.

What you might be looking for:
- [Installing PySoundSphere](https://nmstr.github.io/PySoundSphere/)
- [Usage / Documentation](https://nmstr.github.io/PySoundSphere/usage/)

## License

This project is licensed under the GNU General Public License v3.0 (GPLv3)

See LICENSE.md for more information
